﻿<#
.SYNOPSIS    
Script that returns RAM and RAM-Banks

.PARAMETER Computername 
The computer that will be queried by this script, local administrative permissions are required to query this information.

.DESCRIPTION  
This script uses GET Parameters to request informations

.NOTES
Name: RAM Skript
Author: Frank Kuhn
DateCreated: 2018-06-20 
DateUpdated: TBD 
Version: 1.0.0.0

.DISCLAIMER
The sample scripts are provided in their present condition and without any warranty.
All risks arising from the use or execution of the script and documentation are subject
completely your responsibility. In no case the author, or others at the creation, production or
Provision of the script involved parties for any damage (including, without limitation, any loss 
or damage caused by business loss, loss of business, loss of business information or other 
financial losses) resulting from the use or unsuitability to use the sample scripts or documentation.
#>




[Cmdletbinding()]
Param(
    [string]$Computername = "localhost"
)
cls
$PysicalMemory = Get-WmiObject -class "win32_physicalmemory" -namespace "root\CIMV2" -ComputerName $Computername
 
Write-Host "Memory Modules:" -ForegroundColor Green
$PysicalMemory | Format-Table Tag,BankLabel,@{n="Capacity(GB)";e={$_.Capacity/1GB}},Manufacturer,PartNumber,Speed -AutoSize
 
Write-Host "Total Memory:" -ForegroundColor Green
Write-Host "$((($PysicalMemory).Capacity | Measure-Object -Sum).Sum/1GB)GB"
 
$TotalSlots = ((Get-WmiObject -Class "win32_PhysicalMemoryArray" -namespace "root\CIMV2" -ComputerName $Computername).MemoryDevices | Measure-Object -Sum).Sum
Write-Host "`nTotal Memory Slots:" -ForegroundColor Green
Write-Host $TotalSlots
 
$UsedSlots = (($PysicalMemory) | Measure-Object).Count 
Write-Host "`nUsed Memory Slots:" -ForegroundColor Green
Write-Host $UsedSlots
 
If($UsedSlots -eq $TotalSlots)
{
    Write-Host "All memory slots are filled up, none is empty!" -ForegroundColor Yellow
}